function [output] = track_graph_evol(indata,isDirected,isBipartite,dataname)
    %data should be in form of from,to,timetick
    %isDirected and isBipartite are 0/1 values

    %don't want to change input parameters
    data=indata;

    %fix data so that node indices start with 1
    nodeoffset=min(min(data(:,1:2)))-1;
    data(:,1:2)=data(:,1:2)-nodeoffset;

    %fix data so that time ticks start with 1.  T is last timetick.
    timeoffset=min(data(:,3))-1;
    data(:,3)=data(:,3)-timeoffset;
    T=max(data(:,3));

    %set up adjacency matrices
    if (isBipartite == 0 && isDirected == 0) 
        rows=max(max(data(:,1:2)));
        cols=rows;
        adjmatrix=sparse(max(max(data(:,1:2))),max(max(data(:,1:2))));
    else
        rows=max(data(:,1));
        cols=max(data(:,2));
        %we'll use the same sparse representation for directed and bipartite
        adjmatrix=sparse(max(data(:,1)),max(data(:,2)));
    end

    %for each time tick, we want the following:
    output.N=[];
    output.E=[];
    output.GCCsize=[];
    output.GCC2size=[];
    output.Ncomponents=[];
    output.GCCeigens=zeros(3,0);
    output.eigens=zeros(3,0);
    output.diameter=[];
    output.degrees=[];
    output.name=dataname;

    opts.disp=0;

   
    figure
    hold all;
    h=[];
    legends=cellstr('z');
    
    for (t=1:T)
        t
        %find all new edges for this time tick
        newedges=data(find(data(:,3)==t),1:2);

        %add new edges to graph and convert to 0/1
        adjmatrix=spones(adjmatrix+sparse(newedges(:,1),newedges(:,2),1,rows,cols));
        if (isDirected == 0)
            %make sure we have symmetry
            adjmatrix=spones(adjmatrix+sparse(newedges(:,2),newedges(:,1),1,rows,cols));
        end
    
        if (size(newedges,1) >0)
    
            %run computations
            %find N
            [i j] = find(adjmatrix);
            output.E(t)=size(i,1);
            if (isBipartite == 1)
            output.N(t)=length(unique(i)) + length(unique(j));
            else
                output.N(t)=length(union(i,j));
            end
            eigv=eigs(adjmatrix,3,'lm',opts);
            output.eigens(:,t)=eigv(1:3);
        	
   
            %get component information
            compon=getComponents(adjmatrix);
     
     
        
            %get sizes
            [compsizes]=getcompsizes(nonzeros(compon));
            

            %get pdf
            h=plotccsizes(compsizes,t,h);
            if (legends{1}=='z')
                legends{1}=strcat('time',int2str(t));
            else
                legends{length(legends)+1}=strcat('time',int2str(t));
            end
            
            %record sizes
            bigcompsize=  max(compsizes);
            output.GCCsize(t)=bigcompsize;
          
            bigcomp=find(compsizes==max(compsizes));
            bigcomp=bigcomp(1);
            temp=compon;
            temp(find(temp==bigcomp))=0;
            compsizes(bigcomp)=0;
            secondcompsize=max(compsizes);
            output.GCC2size(t)=secondcompsize;
    
            output.Ncomponents(t)=max(compon);

            if (isDirected==2)
                indices=find(compon==bigcomp);
                eigv=eig(adjmatrix(indices,indices));
                [first i]=max(eigv);
            eigv(i)=[];
            [second i] = max(eigv);
            eigv(i)=[];
            [third i] = max(eigv);
                output.GCCeigens(:,t)= [first second third];
            else
            	indices=find(compon==bigcomp);
                eigv=eigs(adjmatrix(indices,indices),min(3,bigcompsize),'lm',opts);
                if (bigcompsize<3)
                    output.GCCeigens(:,t)=[0 0 0];
                    output.GCCeigens(1:bigcompsize,t)=eigv(1:bigcompsize);
                else
                    output.GCCeigens(:,t)=eigv(1:3);
                end
            end
        else %just copy previous values
            output.N(t)=output.N(t-1);
            output.E(t)=output.E(t-1);
            output.GCCsize(t)=output.GCCsize(t-1);
            output.GCC2size(t)=output.GCC2size(t-1);
            output.Ncomponents(t)=output.Ncomponents(t-1);
            output.GCCeigens(:,t)=output.GCCeigens(:,t-1);
            output.eigens(:,t)=output.eigens(:,t-1);
%            output.degrees(t)=output.degrees(t-1);
        end
    
    end
    legend(legends)
    xlim([1 10000])
    ylim([1 1000])
    hold off;
    set(gca,'XScale','log')
    set(gca,'YScale','log')
    
    set(gcf,'PaperPositionMode','auto')
    print(strcat('ADAGE-plots','/',dataname,'-components','.ps'))
end

function [out] = plotccsizes(sizes,time,h)

myhist=zeros(1,max(sizes));
for (i=1:max(sizes))
   myhist(i) = length(find(sizes==i));
end
out=h;
out(length(h)+1)=loglog(myhist,'-x')

end

